<?php
/**
 * Theme functions and definitions
 *
 * Set up the theme and provides some helper functions, which are used in the
 * theme as custom template tags. Others are attached to action and filter
 * hooks in WordPress to change core functionality.
 *
 * When using a child theme you can override certain functions (those wrapped
 * in a function_exists() call) by defining them first in your child theme's
 * functions.php file. The child theme's functions.php file is included before
 * the parent theme's file, so the child theme functions would be used.
 */

if ( ! function_exists( 'reel_setup' ) ) :
/**
 * Theme setup.
 *
 * Set up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support post thumbnails.
 */
function reel_setup() {
    // This theme styles the visual editor to resemble the theme style.
    add_editor_style( array( 'css/editor-style.css' ) );

    /* Homepage Slider */
    add_image_size( 'featured', 2000 );
    add_image_size( 'featured-small', 1000 );

    add_image_size( 'recent-thumbnail', 720, 400, true );
    add_image_size( 'entry-cover', 2000 );
    add_image_size( 'loop', 505, 335, true );
    add_image_size( 'loop-retina', 1110, 670, true );

    add_image_size( 'portfolio_item-thumbnail', 600, 338, true );
    add_image_size( 'portfolio_item-thumbnail-retina', 1200, 676, true );


    /*
     * Switch default core markup for search form, comment form, and comments
     * to output valid HTML5.
     */
    add_theme_support( 'html5', array(
        'search-form', 'comment-form', 'comment-list', 'gallery', 'caption'
    ) );

    // Register nav menus
    register_nav_menus( array(
        'primary' => __( 'Main Menu', 'wpzoom' )
    ) );

    /*
     * Let WordPress manage the document title.
     * By adding theme support, we declare that this theme does not use a
     * hard-coded <title> tag in the document head, and expect WordPress to
     * provide it for us.
     */
    add_theme_support( 'title-tag' );


    /*  Add support for Custom Background
    ==================================== */
    add_theme_support( 'custom-background' );


    /*
     * JetPack Infinite Scroll
     */
    add_theme_support( 'infinite-scroll', array(
        'container' => 'recent-posts',
        'wrapper' => false,
        'footer' => false
    ) );

    /**
     * Theme Logo
     */
    add_theme_support( 'custom-logo', array(
        'height'      => 90,
        'width'       => 370,
        'flex-height' => true,
        'flex-width'  => true
    ) );

    /**
    * Gutenberg Wide Images
    */
    add_theme_support( 'align-wide' );

    // Add support for default block styles.
    add_theme_support( 'wp-block-styles' );

    // Add support for editor styles.
    add_theme_support( 'editor-styles' );

    // Enqueue editor styles.
    add_editor_style( 'css/gutenberg-editor-style.css' );

    // Enqueue fonts in the editor.
    add_editor_style( reel_fonts_editor() );


    /**
     * Custom colors for use in the editor.
     *
     * @link https://wordpress.org/gutenberg/handbook/reference/theme-support/
     */
    add_theme_support(
        'editor-color-palette', array(
            array(
                'name'  => esc_html__( 'Green', 'wpzoom' ),
                'slug'  => 'green',
                'color' => '#32D8BF',
            ),
            array(
                'name'  => esc_html__( 'Blue', 'wpzoom' ),
                'slug'  => 'blue',
                'color' => '#4176FB',
            ),
            array(
                'name'  => esc_html__( 'Brown', 'wpzoom' ),
                'slug'  => 'brown',
                'color' => '#d19731',
            ),
            array(
                'name'  => esc_html__( 'Red', 'wpzoom' ),
                'slug'  => 'red',
                'color' => '#e1051e',
            ),
            array(
                'name'  => esc_html__( 'Black', 'wpzoom' ),
                'slug'  => 'black',
                'color' => '#101010',
            ),
            array(
                'name'  => esc_html__( 'Gray', 'wpzoom' ),
                'slug'  => 'gray',
                'color' => '#727477',
            ),
            array(
                'name'  => esc_html__( 'White', 'wpzoom' ),
                'slug'  => 'white',
                'color' => '#ffffff',
            ),
            array(
                'name'  => esc_html__( 'Titan White', 'wpzoom' ),
                'slug'  => 'titan-white',
                'color' => '#E0D8E2',
            ),
            array(
                'name'  => esc_html__( 'Peppermint', 'wpzoom' ),
                'slug'  => 'peppermint',
                'color' => '#d0eac4',
            ),

            array(
                'name'  => esc_html__( 'Bridesmaid', 'wpzoom' ),
                'slug'  => 'bridesmaid',
                'color' => '#FBE7DD',
            ),

        )
    );

    migrate_theme_options();

    reel_load_bb_templates();
}
endif;
add_action( 'after_setup_theme', 'reel_setup' );


/* Tell the WPZOOM Framework in which theme we're in
==================================== */

add_theme_support( 'wpz-theme-info', array(
   //Theme Name
   'name' => 'Reel'
) );


/*  Add support for Post Type Order Module
==================================== */
add_theme_support( 'wpz-featured-posts-settings', array(
        array(
            //Unique Id that is used to add the new column in posts list table.
            'id'          => 'wpzoom_is_featured_id',
            //Label that appears in the submenu of post types
            'menu_title'  => __( 'Re-order', 'wpzoom' ),
            //Post type in which this feature will be added.
            'post_type'   => 'slider',
            // Limit the featured post that is show on page.
            'posts_limit' => option::get( 'featured_posts_posts' ),
            // if is true the Featured Posts will be show in this post type.
            'show'        => true
        ),
        array(
            //Unique Id that is used to add the new column in posts list table.
            'id'          => 'wpzoom_is_featured_id',
            //Label that appears in the submenu of post types
            'menu_title'  => __( 'Re-order', 'wpzoom' ),
            //Post type in which this feature will be added.
            'post_type'   => 'portfolio_item',
            // Limit the featured post that is show on page.
            'posts_limit' => option::get( 'portfolio_posts' ),
            // if is true the Featured Posts will be show in this post type.
            'show'        => true
        )
    )
);


/* This theme uses a Static Page as front page.
================================================= */

add_theme_support('zoom-front-page-type', array(
   'type' => 'static_page'
));


/* Portfolio Module @ ZOOM Framewowk
================================== */

add_theme_support( 'zoom-portfolio' );


if ( ! function_exists( 'reel_filter_portfolio' ) ) :
    /**
     * Set posts_per_page limit if is portfolio taxonomy.
     *
     * @param $query
     *
     * @return mixed
     */
    function reel_filter_portfolio( $query ) {
        if ( !is_admin() && $query->is_main_query() && $query->is_tax( 'portfolio' ) ) {
            $query->set( 'posts_per_page', option::get( 'portfolio_posts' ) );
        }

        return $query;
    }
endif;

add_action( 'pre_get_posts', 'reel_filter_portfolio' );


/* Flush rewrite rules for custom post types.
=============================================== */

add_action( 'after_switch_theme', 'flush_rewrite_rules' );


/*  Recommended Plugins
========================================== */

function zoom_register_theme_required_plugins_callback($plugins){

    $plugins =  array_merge(array(

        array(
            'name'         => 'Jetpack',
            'slug'         => 'jetpack',
            'required'     => false,
        ),

        array(
            'name'     => 'Beaver Builder',
            'slug'     => 'beaver-builder-lite-version',
            'required' => true,
        ),

        array(
            'name'     => 'WPZOOM Addons for Beaver Builder',
            'slug'     => 'wpzoom-addons-for-beaver-builder',
            'required' => true,
        ),

        array(
           'name'     => 'Category Order and Taxonomy Terms Order',
           'slug'     => 'taxonomy-terms-order',
           'required' => false,
       ),

        array(
            'name'         => 'Instagram Widget by WPZOOM',
            'slug'         => 'instagram-widget-by-wpzoom',
            'required'     => false,
        )

    ), $plugins);

    return $plugins;
}
add_filter('zoom_register_theme_required_plugins', 'zoom_register_theme_required_plugins_callback');


if ( ! function_exists( 'is_blog' ) ) :
    /**
     * Verify if is blog.
     *
     * @return bool
     */
    function is_blog() {
        global $post;
        $posttype = get_post_type( $post );

        return ( ( $posttype == 'post' ) && ( is_home() || is_single() || is_archive() || is_category() || is_tag() || is_author() ) ) ? true : false;
    }
endif;
/**
 * Fix blog link on current page parent.
 *
 * @param $classes
 * @param $item
 * @param $args
 *
 * @return mixed
 */
if ( ! function_exists( 'fix_blog_link_on_cpt' ) ) :
    function fix_blog_link_on_cpt( $classes, $item, $args ) {
        if ( ! is_blog() ) {
            $blog_page_id = intval( get_option( 'page_for_posts' ) );
            if ( $blog_page_id != 0 && $item->object_id == $blog_page_id ) {
                unset( $classes[ array_search( 'current_page_parent', $classes ) ] );
            }
        }

        return $classes;
    }
endif;

add_filter( 'nav_menu_css_class', 'fix_blog_link_on_cpt', 10, 3 );



/* Get related posts based on portfolios.
==================================== */
function su_portfolio_item_get_related_items( $post_id, $count = 6 )  {
    $portfolios = array();
    $related_terms = get_the_terms( $post_id, 'portfolio' );

    /* return empty query if post doesn't been added to any portfolio */
    if ( ! is_array( $related_terms ) ) return new WP_Query();

    foreach( get_the_terms( $post_id, 'portfolio' ) as $portfolio ) {
        $portfolios[] = $portfolio->term_id;
    }
    $query = new WP_Query();
    $query->query( array(
        'post_type' => 'portfolio_item',
        'tax_query' => array(
            array(
                'taxonomy' => 'portfolio',
                'field' => 'id',
                'terms' => $portfolios
            )
        ),
        'posts_per_page' => $count,
        'post__not_in' => array( $post_id )
    ) );

    return $query;
}


/*  Add Support for Shortcodes in Excerpt
========================================== */

add_filter( 'the_excerpt', 'shortcode_unautop' );
add_filter( 'the_excerpt', 'do_shortcode' );

add_filter( 'widget_text', 'shortcode_unautop' );
add_filter( 'widget_text', 'do_shortcode' );


/*  Custom Excerpt Length
==================================== */

if ( ! function_exists( 'new_excerpt_length' ) ) :

    function new_excerpt_length( $length ) {
        return (int) option::get( "excerpt_length" ) ? (int)option::get( "excerpt_length" ) : 50;
    }

endif;

add_filter( 'excerpt_length', 'new_excerpt_length' );



/* Enable Excerpts for Pages
==================================== */

if ( ! function_exists( 'wpzoom_excerpts_to_pages' ) ) :
    /**
     * Add excerpt page support.
     */
    function wpzoom_excerpts_to_pages() {
        add_post_type_support( 'page', 'excerpt' );
    }
endif;

add_action( 'init', 'wpzoom_excerpts_to_pages' );


/* Exclude specific images from being used in Jetpack's Lazy Load
=========================================== */

add_filter( 'jetpack_lazy_images_blacklisted_classes', 'reel_exclude_custom_classes_from_lazy_load', 999, 1 );

if ( ! function_exists( 'reel_exclude_custom_classes_from_lazy_load' ) ) :

    function reel_exclude_custom_classes_from_lazy_load( $classes ) {
        $classes[] = 'size-portfolio_item-thumbnail';
        $classes[] = 'size-portfolio_item-thumbnail-retina';
        $classes[] = 'attachment-portfolio-scroller-widget';
        return $classes;
    }
endif;


/* Disable Jetpack Related Posts on Post Type
========================================== */

function reel_no_related_posts( $options ) {
    if ( !is_singular( 'post' ) ) {
        $options['enabled'] = false;
    }
    return $options;
}
add_filter( 'jetpack_relatedposts_filter_options', 'reel_no_related_posts' );




/*  Let users change "Older Posts" button text from Jetpack Infinite Scroll
=========================================================================== */

function reel_infinite_scroll_js_settings( $settings ) {
    $settings['text'] = esc_js( esc_html( option::get( 'infinite_scroll_handle_text' ) ) );

    return $settings;
}
add_filter( 'infinite_scroll_js_settings', 'reel_infinite_scroll_js_settings' );




/*  Maximum width for images in posts
=========================================== */

if ( ! isset( $content_width ) ) $content_width = 1400;

function reel_content_width() {
    if ( is_page_template( 'page-templates/full-width-builder.php' ) || is_page_template( 'page-templates/full-width-bb.php' ) ||  is_page_template( 'page-templates/homepage-builder.php' ) || is_page_template( 'page-templates/homepage-builder-bb.php' )) {
            global $content_width;
           $content_width = 2800;
   }
}

add_action( 'template_redirect', 'reel_content_width' );



/* Changing "content_width" parameter for Vimeo videos.
========================================================= */

if ( ! function_exists( 'reel_vimeo_embed_defaults' ) ) :
    /**
     * Changing "content_width" parameter for Vimeo videos.
     *
     * @param $args
     * @param $url
     *
     * @return mixed
     */
    function reel_vimeo_embed_defaults( $args, $url ) {
        $wp_oembed = _wp_oembed_get_object();

        $provider = $wp_oembed->get_provider( $url, array( 'discover' => false ) );

        if ( is_admin() &&
             wp_doing_ajax() &&
             isset( $_POST['action'] ) &&
             $_POST['action'] === 'attach_remote_video_thumb' &&
             ! empty( $provider ) &&
             ( strpos( $provider, 'vimeo' ) !== false )
        ) {
            $args['width'] = 1400;
        }

        return $args;
    }
endif;

add_filter( 'embed_defaults', 'reel_vimeo_embed_defaults', 10, 2 );



if ( ! function_exists( 'reel_get_the_archive_title' ) ) :

/* Custom Archives titles.
=================================== */
function reel_get_the_archive_title( $title ) {
    if ( is_category() ) {
        $title = single_cat_title( '', false );
    }

    return $title;
}
endif;
add_filter( 'get_the_archive_title', 'reel_get_the_archive_title' );




/* Add special class to every post that has an embed code
============================================================ */

function category_id_class( $classes ) {
    global $post;

    if ( false !== ( $ec = get_post_meta( $post->ID, 'wpzoom_post_embed_code', true ) ) && trim( $ec ) != '' ) {
        $classes[] = 'wpz-has-embed-code';
    }

    return $classes;
}
add_filter( 'post_class', 'category_id_class' );




/* Register Custom Fields in Profile: Facebook, Twitter
===================================================== */

add_action( 'show_user_profile', 'my_show_extra_profile_fields' );
add_action( 'edit_user_profile', 'my_show_extra_profile_fields' );

function my_show_extra_profile_fields( $user ) { ?>

    <h3><?php _e('Additional Profile Information', 'wpzoom'); ?></h3>

    <table class="form-table">


        <tr>
            <th><label for="twitter"><?php _e('Twitter Username', 'wpzoom'); ?></label></th>

            <td>
                <input type="text" name="twitter" id="twitter" value="<?php echo esc_attr( get_the_author_meta( 'twitter', $user->ID ) ); ?>" class="regular-text" /><br />
                <span class="description"><?php _e('Please enter your Twitter username', 'wpzoom'); ?></span>
            </td>
        </tr>

        <tr>
            <th><label for="facebook_url"><?php _e('Facebook Profile URL', 'wpzoom'); ?></label></th>

            <td>
                <input type="text" name="facebook_url" id="facebook_url" value="<?php echo esc_attr( get_the_author_meta( 'facebook_url', $user->ID ) ); ?>" class="regular-text" /><br />
                <span class="description"><?php _e('Please enter your Facebook profile URL', 'wpzoom'); ?></span>
            </td>
        </tr>

        <tr>
            <th><label for="facebook_url"><?php _e('Instagram Username', 'wpzoom'); ?></label></th>

            <td>
                <input type="text" name="instagram_url" id="instagram_url" value="<?php echo esc_attr( get_the_author_meta( 'instagram_url', $user->ID ) ); ?>" class="regular-text" /><br />
                <span class="description"><?php _e('Please enter your Instagram username', 'wpzoom'); ?></span>
            </td>
        </tr>

    </table>
<?php }

add_action( 'personal_options_update', 'my_save_extra_profile_fields' );
add_action( 'edit_user_profile_update', 'my_save_extra_profile_fields' );

function my_save_extra_profile_fields( $user_id ) {

    if ( !current_user_can( 'edit_user', $user_id ) )
        return false;

    update_user_meta( $user_id, 'instagram_url', $_POST['instagram_url'] );
    update_user_meta( $user_id, 'facebook_url', $_POST['facebook_url'] );
    update_user_meta( $user_id, 'twitter', $_POST['twitter'] );
}



/* Disable Unyson shortcodes with the same name as in ZOOM Framework
====================================================================== */

function _filter_theme_disable_default_shortcodes($to_disable) {
    $to_disable[] = 'tabs';
    $to_disable[] = 'button';

    return $to_disable;
}
add_filter('fw_ext_shortcodes_disable_shortcodes', '_filter_theme_disable_default_shortcodes');



if ( ! function_exists( 'fw_get_category_term_list' ) ) :
    /**
     * Function that return an array of categories by post_type.
     *
     * @return array - array of available categories
     */
    function fw_get_category_term_list( $post_type = 'post' ) {

        $args   = array(
            'hide_empty' => true,
            'taxonomy'   => 'category'
        );

        if ( $post_type === 'portfolio' ) {
            $args   = array(
                'hide_empty' => true,
                'taxonomy'   => 'portfolio'
            );
        } elseif ( $post_type === 'product' ) {
            $args   = array(
                'hide_empty' => true,
                'taxonomy'   => 'product_cat'
            );
        }

        $terms  = get_terms( $args );
        $result = wp_list_pluck( $terms, 'name', 'term_id' );

        return array( 0 => esc_html__( 'All Categories', 'fw' ) ) + $result;
    }
endif;



/**
 * Show custom logo or blog title and description (backward compatibility)
 *
 */
function reel_custom_logo()
{

    has_custom_logo() ? the_zoom_custom_logo() : printf('<h1><a href="%s" title="%s">%s</a></h1>', home_url(), get_bloginfo('description'), get_bloginfo('name'));

}


/**
 *
 * Register Beaver Builder Templates in our theme
 *
 */
function reel_load_bb_templates() {

    if ( ! class_exists( 'FLBuilder' ) || ! method_exists( 'FLBuilder', 'register_templates' ) ) {
        return;
    }

    FLBuilder::register_templates( get_template_directory() . '/functions/bb-templates/homepage.dat' );
    FLBuilder::register_templates( get_template_directory() . '/functions/bb-templates/about.dat' );
    FLBuilder::register_templates( get_template_directory() . '/functions/bb-templates/services.dat' );
}


/**
 *
 * Old Customizer backward compatibility.
 * Migrate Theme Options to Customizer
 *
 */
if ( ! function_exists( 'migrate_theme_options' ) ) :
    function migrate_theme_options() {

        $prefix = option::$prefix;

        /**
         * Homepage Slider
         */

        // Define defaults if option value is null
        $slider_show     = option::get( 'featured_posts_show' ) != '' ? option::get( 'featured_posts_show' ) : 'on';
        $slider_autoplay = option::get( 'slideshow_auto' ) != '' ? option::get( 'slideshow_auto' ) : 'off';
        $slider_speed    = option::get( 'slideshow_speed' ) != '' ? option::get( 'slideshow_speed' ) : '3000';
        $slider_title    = option::get( 'slideshow_title' ) != '' ? option::get( 'slideshow_title' ) : 'on';
        $slider_excerpt  = option::get( 'slideshow_excerpt' ) != '' ? option::get( 'slideshow_excerpt' ) : 'on';
        $slider_arrows   = option::get( 'slideshow_arrows' ) != '' ? option::get( 'slideshow_arrows' ) : 'on';
        $slider_overlay  = option::get( 'slideshow_overlay' ) != '' ? option::get( 'slideshow_overlay' ) : 'on';
        $slider_effect   = option::get( 'slideshow_effect' ) != '' ? strtolower( option::get( 'slideshow_effect' ) ) : 'slide';
        $slider_posts    = option::get( 'featured_posts_posts' ) != '' ? option::get( 'featured_posts_posts' ) : '5';

        if ( get_option( $prefix . 'featured_posts_show' ) ) {
            set_theme_mod( 'featured_posts_show', $slider_show );
            delete_option( $prefix . 'featured_posts_show' );
        }

        if ( get_option( $prefix . 'slideshow_auto' ) ) {
            set_theme_mod( 'slideshow_auto', $slider_autoplay );
            delete_option( $prefix . 'slideshow_auto' );
        }

        if ( get_option( $prefix . 'slideshow_speed' ) ) {
            set_theme_mod( 'slideshow_speed', $slider_speed );
            delete_option( $prefix . 'slideshow_speed' );
        }

        if ( get_option( $prefix . 'slideshow_title' ) ) {
            set_theme_mod( 'slideshow_title', $slider_title );
            delete_option( $prefix . 'slideshow_title' );
        }

        if ( get_option( $prefix . 'slideshow_excerpt' ) ) {
            set_theme_mod( 'slideshow_excerpt', $slider_excerpt );
            delete_option( $prefix . 'slideshow_excerpt' );
        }

        if ( get_option( $prefix . 'slideshow_arrows' ) ) {
            set_theme_mod( 'slideshow_arrows', $slider_arrows );
            delete_option( $prefix . 'slideshow_arrows' );
        }

        if ( get_option( $prefix . 'slideshow_overlay' ) ) {
            set_theme_mod( 'slideshow_overlay', $slider_overlay );
            delete_option( $prefix . 'slideshow_overlay' );
        }

        if ( get_option( $prefix . 'slideshow_effect' ) ) {
            set_theme_mod( 'slideshow_effect', $slider_effect );
            delete_option( $prefix . 'slideshow_effect' );
        }

        if ( get_option( $prefix . 'featured_posts_posts' ) ) {
            set_theme_mod( 'featured_posts_posts', $slider_posts );
            delete_option( $prefix . 'featured_posts_posts' );
        }
    }
endif;




if ( ! function_exists( 'reel_get_google_font_uri' ) ) :
    /**
     * Build the HTTP request URL for Google Fonts.
     *
     * @return string    The URL for including Google Fonts.
     */
    function reel_get_google_font_uri() {
        // Grab the font choices
        $font_keys = zoom_customizer_get_font_familiy_ids(reel_customizer_data());

        $fonts = array();
        foreach ( $font_keys as $key => $default ) {
            $fonts[] = get_theme_mod( $key, $default );
        }

        // De-dupe the fonts
        $fonts         = array_unique( $fonts );
        $allowed_fonts = zoom_customizer_get_google_fonts();
        $family        = array();

        // Validate each font and convert to URL format
        foreach ( $fonts as $font ) {
            $font = trim( $font );

            // Verify that the font exists
            if ( array_key_exists( $font, $allowed_fonts ) ) {
                // Build the family name and variant string (e.g., "Open+Sans:regular,italic,700")
                $family[] = urlencode( $font . ':' . join( ',', zoom_customizer_choose_google_font_variants( $font, $allowed_fonts[ $font ]['variants'] ) ) );
            }
        }

        // Convert from array to string
        if ( empty( $family ) ) {
            return '';
        } else {
            $request = '//fonts.googleapis.com/css?family=' . implode( '|', $family );
        }

        // Load the font subset
        $subset = get_theme_mod( 'font-subset', false );

        if ( 'all' === $subset ) {

            $subsets_available = zoom_customizer_get_google_font_subsets();

            // Remove the all set
            unset( $subsets_available['all'] );

            // Build the array
            $subsets = array_keys( $subsets_available );
        } else {
            $subsets = array(
                'latin',
                $subset,
            );
        }

        // Append the subset string
        if ( ! empty( $subsets ) ) {
            $request .= urlencode( '&subset=' . join( ',', $subsets ) );
        }

        /**
         * Filter the Google Fonts URL.
         *
         * @since 1.2.3.
         *
         * @param string    $url    The URL to retrieve the Google Fonts.
         */
        return apply_filters( 'reel_get_google_font_uri', esc_url( $request ) );
    }
endif;



/* Enqueue scripts and styles for the front end.
=========================================== */

if ( ! function_exists( 'reel_scripts' ) ) :

    function reel_scripts() {

        $data = reel_customizer_data();

        // Load our main stylesheet.
        if ( '' !== $google_request = reel_get_google_font_uri() ) {
            wp_enqueue_style( 'reel-google-fonts', $google_request, WPZOOM::$themeVersion );
        }
        wp_enqueue_style( 'reel-style', get_stylesheet_uri(), array(), WPZOOM::$themeVersion );

        wp_enqueue_style( 'media-queries', get_template_directory_uri() . '/css/media-queries.css', array(), WPZOOM::$themeVersion );

        wp_enqueue_style( 'reel-google-font-default', '//fonts.googleapis.com/css?family=Karla:400,400i,700,700i|Work+Sans:400,800&amp;subset=latin-ext' );

        wp_enqueue_style( 'dashicons' );

        wp_enqueue_script( 'slicknav', get_template_directory_uri() . '/js/jquery.slicknav.min.js', array( 'jquery' ), WPZOOM::$themeVersion, true );

        wp_enqueue_script( 'flexslider', get_template_directory_uri() . '/js/flexslider.min.js', array( 'jquery' ), WPZOOM::$themeVersion, true );

        wp_enqueue_script( 'fitvids', get_template_directory_uri() . '/js/fitvids.min.js', array( 'jquery' ), WPZOOM::$themeVersion, true );

        wp_enqueue_script( 'imagesLoaded', get_template_directory_uri() . '/js/imagesLoaded.min.js', array(), WPZOOM::$themeVersion, true );

        wp_enqueue_style( 'magnificPopup', get_template_directory_uri() . '/css/magnific-popup.css', array(), WPZOOM::$themeVersion );

        wp_enqueue_style( 'formstone-background', get_template_directory_uri() . '/css/background.css', array(), WPZOOM::$themeVersion );

        wp_enqueue_script( 'magnificPopup', get_template_directory_uri() . '/js/jquery.magnific-popup.min.js', array(), WPZOOM::$themeVersion, true );

        wp_enqueue_script( 'flickity', get_template_directory_uri() . '/js/flickity.pkgd.min.js', array(), WPZOOM::$themeVersion, true );

        wp_enqueue_script( 'superfish', get_template_directory_uri() . '/js/superfish.min.js', array( 'jquery' ), WPZOOM::$themeVersion, true );

        wp_enqueue_script( 'headroom', get_template_directory_uri() . '/js/headroom.min.js', array( 'jquery' ), WPZOOM::$themeVersion, true );

        wp_enqueue_script( 'search_button', get_template_directory_uri() . '/js/search_button.js', array(), WPZOOM::$themeVersion, true );

        wp_enqueue_script( 'jquery.parallax', get_template_directory_uri() . '/js/jquery.parallax.js', array( 'jquery' ), WPZOOM::$themeVersion, true );

        // Enqueue Isotope when Portfolio Isotope template is used.
        // if ( is_page_template( 'portfolio/archive-isotope.php' ) ) {
            wp_enqueue_script( 'isotope', get_template_directory_uri() . '/js/isotope.pkgd.min.js', array('wp-util' ), WPZOOM::$themeVersion, true );
        // }

        $themeJsOptions = array_merge( option::getJsOptions(), option::getCustomizerJsOptions() );

        wp_enqueue_script( 'reel-script', get_template_directory_uri() . '/js/functions.js', array( 'jquery' ), WPZOOM::$themeVersion, true );

        wp_localize_script( 'reel-script', 'zoomOptions', $themeJsOptions );

        if (
            is_page_template( 'page-templates/homepage-builder.php' ) ||
            is_page_template( 'page-templates/homepage-builder-bb.php' ) ||
            is_page_template( 'page-templates/homepage-portfolio.php' ) ||
            is_page_template( 'page-templates/homepage-portfolio-infinite.php' ) ||
            is_front_page()

        ) {
            // Vimeo API
            wp_enqueue_script( 'vimeo_iframe_api', 'https://player.vimeo.com/api/player.js', array( 'jquery' ), false, true );
        }
    }
endif;

add_action( 'wp_enqueue_scripts', 'reel_scripts' );


/**
 * Enqueue scripts and styles needed for Gutenberg and admin area.
 ================================================== */

function reel_block_scripts() {

    // Add custom fonts, used in the main stylesheet.
    wp_enqueue_style( 'reel-fonts', reel_fonts_editor(), false, '@@pkg.version', 'all' );

    wp_enqueue_style( 'wpzoom-video-embed', get_template_directory_uri() . '/css/admin-video.css', array(), WPZOOM::$themeVersion );

}
add_action( 'admin_enqueue_scripts', 'reel_block_scripts' );



/**
 * Register custom fonts in Gutenberg.
 ================================================== */

function reel_fonts_editor() {
    $fonts_url = '';

    $font_families = array();
        $font_families[] = 'Karla:400,400i,700,700i|Work Sans:400,800';
        $query_args = array(
            'family' => rawurlencode( implode( '|', $font_families ) ),
            'subset' => rawurlencode( 'latin,latin-ext' ),
        );
        $fonts_url = add_query_arg( $query_args, 'https://fonts.googleapis.com/css' );
    return esc_url_raw( $fonts_url );
}


/* Enqueue Formstone-related scripts (video background)
================================================== */

if ( ! function_exists( 'reel_video_scripts' ) ) :
    function reel_video_scripts() {

        wp_enqueue_script( 'formstone-core', get_template_directory_uri() . '/js/formstone/core.js', array(
            'jquery',
            'underscore'
        ), WPZOOM::$themeVersion, true );

        wp_enqueue_script( 'formstone-transition', get_template_directory_uri() . '/js/formstone/transition.js', array( 'jquery' ), WPZOOM::$themeVersion, true );

        wp_enqueue_script( 'formstone-background', get_template_directory_uri() . '/js/formstone/background.js', array( 'jquery' ), WPZOOM::$themeVersion, true );

    }
endif;

add_action( 'wp_enqueue_scripts', 'reel_video_scripts', 100 );

if ( ! function_exists( 'array_to_data_atts' ) ) :
    function array_to_data_atts( $in ) {
        $result = '';
        foreach ( $in as $key => $value ) {
            $result .= " " . $key . '="' . $value . '" ';
        }

        return $result;
    }
endif;


/**
 *
 * Ajax callback function for filter from archive-isotope.php and archive-clean.php
 * that return html output from the portfolio/content or portfolio/content-clean templates.
 *
 */
function wpz_get_portfolio_filtered_items() {

    ob_start();

    if ( ! wp_verify_nonce( $_POST['nonce'], 'wpz_get_portfolio_filtered_items' ) ) {
        wp_send_json_error( array( 'message' => 'Invalid nonce' ) );
    }

    if ( empty( $_POST['tmpl'] ) || empty( $_POST['category_id'] ) ) {
        wp_send_json_error( array( 'message' => 'Empty $_POST data' ) );
    }

    $tmpl        = sanitize_text_field( $_POST['tmpl'] );
    $category_id = sanitize_text_field( $_POST['category_id'] );

    if ( ! empty( $category_id ) &&
         ! empty( $tmpl ) &&
         in_array( $tmpl, array( 'archive-isotope.php' ) )
    ) {

        $tmpl = 'archive-isotope.php' === $tmpl ? 'portfolio/content' : 'portfolio/content';
        $args = array(
            'post_type'      => 'portfolio_item',
            'posts_per_page' => - 1,
            'orderby'        => 'menu_order date',
            'tax_query'      => array(
                array(
                    'taxonomy' => 'portfolio',
                    'terms'    => $category_id,
                    'field'    => 'term_id',
                )
            )
        );

        $wp_query = new WP_Query( $args );


        if ( $wp_query->have_posts() ) {
            while ( $wp_query->have_posts() ) {
                $wp_query->the_post();
                get_template_part( $tmpl );
            }
        }


        $content = ob_get_clean();
    }

    wp_send_json_success( array( 'content' => trim( $content ) ) );
}

add_action( 'wp_ajax_nopriv_wpz_get_portfolio_filtered_items', 'wpz_get_portfolio_filtered_items' );
add_action( 'wp_ajax_wpz_get_portfolio_filtered_items', 'wpz_get_portfolio_filtered_items' );